@@ -47,14 +47,16 @@
 #' GRM2 <- GRM[100 + 1:10, 100 + 1:10]
 #' GRM1
 #' GRM2
-#' @export
-GRAB.SimuGMat <- function(nSub,
-                          nFam,
-                          FamMode,
-                          nSNP,
-                          MaxMAF = 0.5,
-                          MinMAF = 0.05,
-                          MAF = NULL) {
+#'
+GRAB.SimuGMat <- function(
+  nSub,
+  nFam,
+  FamMode,
+  nSNP,
+  MaxMAF = 0.5,
+  MinMAF = 0.05,
+  MAF = NULL
+) {
   inputList <- checkInput(nSub, nFam, FamMode)
 
   nSubInEachFam <- inputList$nSubInEachFam
@@ -70,10 +72,8 @@ GRAB.SimuGMat <- function(nSub,
     stop("Please give at least one of 'nSub' and 'nFam'.")
   }
 
-  message("Number of unrelated subjects:\t", nSub)
-  message("Number of families:\t", nFam)
-  message("Number of subjects in each family:\t", nSubInEachFam)
-  message("Number of all subjects:\t", n)
+  .message("Simulation design: %d unrelated subjects, %d families (%d per family)", nSub, nFam, nSubInEachFam)
+  .message("Total subjects: %d", n)
 
   if (is.null(MAF)) {
     MAF <- runif(nSNP, MinMAF, MaxMAF)
@@ -81,7 +81,7 @@ GRAB.SimuGMat <- function(nSub,
     if (length(MAF) != nSNP) {
       stop("length(MAF) should equal to nSNP.")
     }
-    message("Since argument 'MAF' is given, arguments of 'MaxMAF' and 'MinMAF' are ignored.")
+    .message("Using provided MAF values (ignoring MaxMAF and MinMAF)")
   }
 
   SNP.info <- make.SNP.info(nSNP, MAF)
@@ -89,15 +89,15 @@ GRAB.SimuGMat <- function(nSub,
   GenoMat1 <- GenoMat2 <- NULL
 
   if (nHaplo != 0) {
-    message("Simulating haplotype data for related subjects....")
+    .message("Simulating haplotype data for %d related subjects", nHaplo)
     haplo.mat <- haplo.simu(nHaplo, SNP.info)
 
-    message("Simulating genotype data for related subjects....")
+    .message("Converting haplotypes to genotypes")
     GenoMat1 <- from.haplo.to.geno(haplo.mat, fam.mat) # output of example.fam(): n x 5 where n is sample size
   }
 
   if (nSub != 0) {
-    message("Simulationg Genotype data for unrelated subjects....")
+    .message("Simulating genotype data for %d unrelated subjects", nSub)
     GenoMat2 <- geno.simu(nSub, SNP.info)
   }
 
@@ -111,13 +111,13 @@ GRAB.SimuGMat <- function(nSub,
 
 checkInput <- function(nSub, nFam, FamMode) {
   if (missing(FamMode) & missing(nFam)) {
-    message("Since both 'FamMode' and 'nFam' are not specified, we only simulate genotype/bVec for unrelated subjects.")
+    .message("Simulating unrelated subjects only (no family structure specified)")
     nFam <- 0
     FamMode <- "Unrelated"
   }
 
   if (missing(nSub)) {
-    message("Since 'nSub' is not specified, we only simulate genotype for family members.")
+    .message("Simulating family members only (no unrelated subjects)")
     nSub <- 0
   }
 
@@ -159,7 +159,7 @@ checkInput <- function(nSub, nFam, FamMode) {
   return(inputList)
 }
 
-### an example of family structure including 20 memebers in each family
+### an example of family structure including 20 members in each family
 ## 1+2->9+10; 3+9->11+12; 4+10->13+14; 5+11->15+16; 6+12->17; 7+13->18; 8+14->19+20
 example.fam.20.members <- function(n.fam) # family numbers
 {
@@ -191,7 +191,7 @@ example.fam.20.members <- function(n.fam) # family numbers
   return(fam.mat) # five columns of FID, IID, Role, Source1, and Source2
 }
 
-### an example of family structure including 10 memebers in each family
+### an example of family structure including 10 members in each family
 ## 1+2->5+6; 3+5->7+8; 4+6->9+10
 example.fam.10.members <- function(n.fam) # family numbers
 {
@@ -223,7 +223,7 @@ example.fam.10.members <- function(n.fam) # family numbers
   return(fam.mat) # five columns of FID, IID, Role, Source1, and Source2
 }
 
-### an example of family structure including 4 memebers in each family
+### an example of family structure including 4 members in each family
 ## 1+2->3+4
 example.fam.4.members <- function(n.fam) # family numbers
 {
@@ -326,7 +326,7 @@ from.haplo.to.geno <- function(haplo.mat, # output of haplo.simu():  m x p where
   Haplo2.mat <- matrix(nrow = n, ncol = m)
   rownames(Haplo1.mat) <- rownames(Haplo2.mat) <- fam.mat$IID
   for (i in 1:n) { # cycle for all subjects
-    if (i %% 1000 == 0) message("Complete Genotype Simulation for ", i, " Subjects.")
+    if (i %% 1000 == 0) .message("Genotype simulation progress: %d subjects", i)
     Role <- fam.mat$Role[i]
     S1 <- fam.mat$Source1[i]
     S2 <- fam.mat$Source2[i]
@@ -367,7 +367,7 @@ from.haplo.to.geno <- function(haplo.mat, # output of haplo.simu():  m x p where
 #' tau <- 2
 #' bVec <- GRAB.SimubVec(nSub, nFam, FamMode, tau)
 #'
-#' @export
+#'
 GRAB.SimubVec <- function(nSub,
                           nFam,
                           FamMode,
@@ -386,10 +386,8 @@ GRAB.SimubVec <- function(nSub,
     stop("Please give at least one of 'nSub' and 'nFam'.")
   }
 
-  message("Number of unrelated subjects:\t", nSub)
-  message("Number of families:\t", nFam)
-  message("Number of subjects in each family:\t", nSubInEachFam)
-  message("Number of all subjects:\t", n)
+  .message("bVec simulation: %d unrelated subjects, %d families (%d per family)", nSub, nFam, nSubInEachFam)
+  .message("Total subjects: %d", n)
 
   if (FamMode == "Unrelated") {
     bVec.Related <- data.table::data.table()
@@ -469,7 +467,7 @@ GRAB.SimubVec <- function(nSub,
 #'   control = list(IDsToIncludeFile = IDsToIncludeFile)
 #' )
 #'
-#' @export
+#'
 GRAB.SimuGMatFromGenoFile <- function(nFam,
                                       nSub,
                                       FamMode, # "4-members", "10-members", and "20-members"
@@ -492,10 +490,8 @@ GRAB.SimuGMatFromGenoFile <- function(nFam,
     stop("Please give at least one of 'nSub' and 'nFam'.")
   }
 
-  message("Number of unrelated subjects:\t", nSub)
-  message("Number of families:\t", nFam)
-  message("Number of subjects in each family:\t", nSubInEachFam)
-  message("Number of all subjects:\t", n)
+  .message("Genotype matrix simulation: %d unrelated subjects, %d families (%d per family)", nSub, nFam, nSubInEachFam)
+  .message("Total subjects: %d", n)
 
   ####
 
@@ -522,17 +518,17 @@ GRAB.SimuGMatFromGenoFile <- function(nFam,
   rowForSub <- randomRow[1:nSub + nHaplo / 2]
 
   if (nHaplo != 0) {
-    message("Extracting haplotype data for related subjects....")
+    .message("Extracting haplotype data for %d related subjects", nHaplo)
     GenoMatTemp <- GenoMat[rowForHaplo, ]
     haplo.mat <- from.geno.to.haplo(GenoMatTemp)
     rownames(haplo.mat) <- paste0("haplo-", 1:nHaplo)
 
-    message("Simulating genotype data for related subjects....")
+    .message("Converting haplotypes to genotypes for related subjects")
     GenoMat1 <- from.haplo.to.geno(haplo.mat, fam.mat) # output of example.fam(): n x 5 where n is sample size
   }
 
   if (nSub != 0) {
-    message("Extracting Genotype data for unrelated subjects....")
+    .message("Extracting genotype data for %d unrelated subjects", nSub)
     GenoMat2 <- GenoMat[rowForSub, ]
     rownames(GenoMat2) <- paste0("Subj-", 1:nSub)
   }
@@ -597,7 +593,7 @@ GRAB.SimuGMatFromGenoFile <- function(nFam,
 #' # UK Biobank use 'ref-first'
 #' # bgenix -g simuBGEN.bgen --index
 #'
-#' @export
+#'
 GRAB.makePlink <- function(GenoMat,
                            OutputPrefix,
                            A1 = "G",
@@ -628,8 +624,7 @@ GRAB.makePlink <- function(GenoMat,
   m <- length(SNP)
   n <- length(IID)
 
-  message("number of markers:\t", m)
-  message("number of samples:\t", n)
+  .message("Creating PLINK files: %d markers, %d samples", m, n)
 
   if (is.null(Pheno)) {
     Pheno <- rep(-9, n)
@@ -696,9 +691,8 @@ GRAB.makePlink <- function(GenoMat,
   data.table::fwrite(MAP, MAP.file, quote = FALSE, col.names = FALSE, row.names = FALSE, sep = " ")
   data.table::fwrite(PED, PED.file, quote = FALSE, col.names = FALSE, row.names = FALSE, sep = " ")
 
-  message("Working directory:\t", getwd())
-  message("PED file:\t", PED.file)
-  message("MAP file:\t", MAP.file)
+  .message("PLINK files saved to: %s", OutputPrefix)
+  .message("Working directory: %s", getwd())
 
   message <- paste0("PLINK files have been saved to ", OutputPrefix, ".")
   return(message)
@@ -714,7 +708,7 @@ GRAB.makePlink <- function(GenoMat,
 #' @param seed a random number seed for reproducibility
 #' @details Check https://wenjianbi.github.io//grab.github.io/docs/simulation_phenotype.html for more details.
 #' @return a numeric vector of phenotype
-#' @export
+#'
 GRAB.SimuPheno <- function(
     eta,
     traitType = "binary",
@@ -732,19 +726,19 @@ GRAB.SimuPheno <- function(
 
   if (traitType == "quantitative") {
     if (!"sdError" %in% names(control)) {
-      message("For quantitative phenotype, argument 'control' should include 'sdError' which is the stardard derivation of the error term.")
+      .message("Note: For quantitative phenotype, 'control$sdError' should specify error term standard deviation")
     }
   }
 
   if (traitType == "ordinal") {
     if (!"pEachGroup" %in% names(control)) {
-      message("For ordinal categorical phenotype, argument 'control' should include 'pEachGroup' which is ratio of sample size in each group.")
+      .message("Note: For ordinal categorical phenotype, 'control$pEachGroup' should specify group proportions")
     }
   }
 
   if (traitType == "time-to-event") {
     if (!"eventRate" %in% names(control)) {
-      message("For time-to-event phenotype, argument 'control' should include 'eventRate' which is the event rate.")
+      .message("Note: For time-to-event phenotype, 'control$eventRate' should specify event rate")
     }
   }
 
@@ -752,8 +746,6 @@ GRAB.SimuPheno <- function(
   n <- length(eta)
 
   if (!is.null(seed)) set.seed(seed)
-  # seed = sample(1e9,1)
-  # message("Random number seed:\t", seed)
 
   ### quantitative trait
   if (traitType == "quantitative") {
