@@ -12,20 +12,17 @@
 #' @return No return value, called for side effects (prints information about the POLMM method to the console).
 #'
 #' @examples
-#' ### First, Read Data and Convert Phenotype to a Factor
-#' library(dplyr)
+#' ### First, read phenotype data and convert to a factor
 #' PhenoFile <- system.file("extdata", "simuPHENO.txt", package = "GRAB")
 #' PhenoData <- data.table::fread(PhenoFile, header = TRUE)
-#' PhenoData <- PhenoData %>% mutate(OrdinalPheno = factor(OrdinalPheno,
-#'   levels = c(0, 1, 2)
-#' ))
-#'
+#' PhenoData$OrdinalPheno <- factor(PhenoData$OrdinalPheno, levels = c(0, 1, 2))
+#' 
 #' ### Step 1: Fit a null model
-#' # If a sparse GRM is used in model fitting, SparseGRMFile is required.
+#' # If SparseGRMFile is provided, the sparse GRM will be used in model fitting.
 #' # If SparseGRMFile isn't provided, GRAB.NullModel() will calculate dense GRM from GenoFile.
-#'
-#' SparseGRMFile <- system.file("SparseGRM", "SparseGRM.txt", package = "GRAB")
+#' SparseGRMFile <- system.file("extdata", "SparseGRM.txt", package = "GRAB")
 #' GenoFile <- system.file("extdata", "simuPLINK.bed", package = "GRAB")
+#' 
 #' obj.POLMM <- GRAB.NullModel(
 #'   formula = OrdinalPheno ~ AGE + GENDER,
 #'   data = PhenoData,
@@ -42,40 +39,23 @@
 #'   )
 #' )
 #'
-#' objPOLMMFile <- system.file("results", "objPOLMMFile.RData", package = "GRAB")
-#' save(obj.POLMM, file = objPOLMMFile)
-#'
-#'
 #' ### Step 2(a): Single-variant tests using POLMM
-#' objPOLMMFile <- system.file("results", "objPOLMMFile.RData", package = "GRAB")
-#' load(objPOLMMFile) # read in an R object of "obj.POLMM"
-#'
 #' GenoFile <- system.file("extdata", "simuPLINK.bed", package = "GRAB")
-#' OutputDir <- tempdir()
-#' OutputFile <- file.path(OutputDir, "simuMarkerOutput.txt")
-#' GRAB.Marker(obj.POLMM,
+#' OutputFile <- file.path(tempdir(), "simuMarkerOutput.txt")
+#' 
+#' GRAB.Marker(
+#'   objNull = obj.POLMM,
 #'   GenoFile = GenoFile,
 #'   OutputFile = OutputFile
 #' )
 #'
-#' results <- data.table::fread(OutputFile)
-#' hist(results$Pvalue)
-#'
-#'
+#' data.table::fread(OutputFile)
+#' 
 #' ### Step 2(b): Set-based tests using POLMM-GENE
-#' objPOLMMFile <- system.file("results", "objPOLMMFile.RData", package = "GRAB")
-#' load(objPOLMMFile) # read in an R object of "obj.POLMM"
-#'
 #' GenoFile <- system.file("extdata", "simuPLINK_RV.bed", package = "GRAB")
-#' OutputDir <- tempdir()
-#' OutputFile <- file.path(OutputDir, "simuRegionOutput.txt")
+#' OutputFile <- file.path(tempdir(), "simuRegionOutput.txt")
 #' GroupFile <- system.file("extdata", "simuPLINK_RV.group", package = "GRAB")
-#' SparseGRMFile <- system.file("SparseGRM", "SparseGRM.txt", package = "GRAB")
-#'
-#' ## make sure the output files does not exist at first
-#' file.remove(OutputFile)
-#' file.remove(paste0(OutputFile, ".markerInfo"))
-#' file.remove(paste0(OutputFile, ".index"))
+#' SparseGRMFile <- system.file("extdata", "SparseGRM.txt", package = "GRAB")
 #'
 #' GRAB.Region(
 #'   objNull = obj.POLMM,
@@ -90,9 +70,8 @@
 #'
 #' data.table::fread(OutputFile)
 #'
-#' @export
 GRAB.POLMM <- function() {
-  message("Check ?GRAB.POLMM for more details about 'POLMM' method.")
+  .message("Using POLMM method - see ?GRAB.POLMM for details")
 }
 
 ################### This file includes the following functions
@@ -361,14 +340,12 @@ setMarker.POLMM <- function(objNull, control, chrom) {
     control$SPA_Cutoff,
     flagSparseGRM
   )
-
-  message("The current control$nMarkersEachChunk is ", control$nMarkersEachChunk, ".")
 }
 
 # Used in setRegion() function in GRAB_Region.R
 setRegion.POLMM <- function(objNull, control, chrom, SparseGRMFile) {
   if (chrom != "LOCO=F") {
-    message("Argument 'chrom' is:\t", chrom)
+    .message("Chromosome: %s", chrom)
     if (!"LOCOList" %in% names(objNull)) {
       stop("If argument 'chrom' is not 'LOCO=FALSE', then objNull should includes element of 'LOCOList'.")
     }
@@ -378,7 +355,7 @@ setRegion.POLMM <- function(objNull, control, chrom, SparseGRMFile) {
 
   # Since region-level analysis mainly focuses on rare variants, we use sparse GRM for all markers
 
-  message("Sparse GRM is used for POLMM-GENE method.")
+  .message("Using sparse GRM for POLMM-GENE analysis")
 
   setSparseGRMInStep2(SparseGRMFile, objNull) # check SparseGRM.R
 
