@@ -13,7 +13,8 @@
 #' # Step 1: fit a null model
 #' PhenoFile <- system.file("extdata", "simuPHENO.txt", package = "GRAB")
 #' PhenoData <- data.table::fread(PhenoFile, header = TRUE)
-#' obj.SPACox <- GRAB.NullModel(survival::Surv(SurvTime, SurvEvent) ~ AGE + GENDER,
+#' obj.SPACox <- GRAB.NullModel(
+#'   survival::Surv(SurvTime, SurvEvent) ~ AGE + GENDER,
 #'   data = PhenoData,
 #'   subjData = IID,
 #'   method = "SPACox",
@@ -22,11 +23,14 @@
 #'
 #' # Using model residuals performs exactly the same as the above. Note that
 #' # confounding factors are still required in the right of the formula.
-#' obj.coxph <- survival::coxph(survival::Surv(SurvTime, SurvEvent) ~ AGE + GENDER,
+#' obj.coxph <- survival::coxph(
+#'   survival::Surv(SurvTime, SurvEvent) ~ AGE + GENDER,
 #'   data = PhenoData,
 #'   x = TRUE
 #' )
-#' obj.SPACox <- GRAB.NullModel(obj.coxph$residuals ~ AGE + GENDER,
+#' 
+#' obj.SPACox <- GRAB.NullModel(
+#'   obj.coxph$residuals ~ AGE + GENDER,
 #'   data = PhenoData,
 #'   subjData = IID,
 #'   method = "SPACox",
@@ -37,18 +41,20 @@
 #' GenoFile <- system.file("extdata", "simuPLINK.bed", package = "GRAB")
 #' OutputDir <- tempdir()
 #' OutputFile <- file.path(OutputDir, "Results_SPACox.txt")
-#' GRAB.Marker(obj.SPACox,
-#'   GenoFile = GenoFile, OutputFile = OutputFile,
+#' GRAB.Marker(
+#'   objNull = obj.SPACox,
+#'   GenoFile = GenoFile,
+#'   OutputFile = OutputFile,
 #'   control = list(outputColumns = "zScore")
 #' )
 #' data.table::fread(OutputFile)
-#' @export
+#'
 GRAB.SPACox <- function() {
-  message("Check ?GRAB.SPACox for more details about 'SPACox' method.")
+  .message("Using SPACox method - see ?GRAB.SPACox for details")
 }
 
 # check the control list in null model fitting for SPACox method
-checkControl.NullModel.SPACox <- function(control, traitType, ...) {
+checkControl.NullModel.SPACox <- function(control, traitType) {
   if (!traitType %in% c("time-to-event", "Residual")) {
     stop("For 'SPACox' method, only traitType of 'time-to-event' or 'Residual' is supported.")
   }
@@ -137,7 +143,7 @@ fitNullModel.SPACox <- function(response, designMat, subjData, control, ...) {
   idx1 <- idx0 * max(range) / max(idx0)
 
   cumul <- NULL
-  message("Start calculating empirical CGF for martingale residuals...")
+  .message("Calculating empirical CGF for martingale residuals")
   c <- 0
   for (i in idx1) {
     c <- c + 1
@@ -150,7 +156,7 @@ fitNullModel.SPACox <- function(response, designMat, subjData, control, ...) {
     K1 <- M1 / M0
     K2 <- (M0 * M2 - M1^2) / M0^2
     cumul <- rbind(cumul, c(t, K0, K1, K2))
-    if (c %% 1000 == 0) message("Complete ", c, "/", length.out, ".")
+    if (c %% 1000 == 0) .message("CGF progress: %d/%d", c, length.out)
   }
 
   re <- list(
